from setuptools import setup, find_packages

setup(
    name='genai789',                # your package name
    version='0.2.0',             # initial version
    author='Your Name',
    author_email='your.email@example.com',
    description='A collection of 10 code programs as strings',
    packages=find_packages(),    # automatically find genai folder
    python_requires='>=3.6',     # minimum Python version
)
